__author__ = 'Yasas Senarath'
__copyright__ = 'Copyright 2020, Yasas Senarath'
__credits__ = ['Yasas Senarath']
__license__ = 'MIT'
__version__ = '0.0.1'
__maintainer__ = 'Yasas Senarath'
__email__ = 'ysenarath.93@gmail.com'
__status__ = 'Alpha-Production'